#                                               18 December 2020.  SMS.
#
#    Wget 1.20.3 for VMS - MMS (or MMK) Description File.
#
# Usage:
#
#    SET DEFAULT [.directory]   ! [.VMS] to build all products.
#    MMS /DESCRIPTION = [-.VMS] [/MACRO = (<see_below>)] target
#
# Optional macros:
#
#    CCOPTS=xxx     Compile with CC options xxx.  For example:
#                   "CCOPTS=/ARCH=HOST"
#
#    CDEFS_USER=xxx  Compile with C macro definition(s) xxx.
#
#    DBG=1          Compile /DEBUG /NOOPTIMIZE.  Link /DEBUG /TRACEBACK.
#    TRC=1          Default is /NOTRACEBACK, but TRC=1 enables link with
#                   /TRACEBACK without compiling for debug.
#
#    HPSSL=1        Enable HTTPS (and NTLM) support using HP SSL. 
#                   (SSL$ROOT)
#    HPSSL1=1       Enable HTTPS (and NTLM) support using HP SSL1.
#                   (SSL1$ROOT)
#
#    LARGE=1        Enable/disable large-file (>2GB) support.  Always
#    NOLARGE=1      disabled on VAX.  Enabled by default on Alpha and
#                   IA64.  On Alpha, by default, large-file support is
#                   tested, and the build will fail if that test fails.
#                   Specify LARGE=1 (or NOLARGE=1) explicitly to enable
#                   (or disable) support, and to skip the test on Alpha.
#
#    LINKOPTS=xxx   Link with LINK options xxx.  For example:
#                   "LINKOPTS=/NOINFO"
#
#    LIST=1         Compile with /LIST /SHOW = (ALL, NOMESSAGES).
#                   Link with /MAP /CROSS_REFERENCE /FULL.
#
#    NODASHD=1      Compile with -d/--debug option disabled.
#
#    OSSL=1         Enable HTTPS (and NTLM) support using OpenSSL
#                   version before "1.1.1".  (SSLROOT)
#
#    OSSLD=1        Enable HTTPS (and NTLM) support using OpenSSL
#                   version "1.1.1" or later.  (OSSL$ROOT)
#
#    OSSLOLB=1      Use OpenSSL object libraries (.OLB), even if shared
#                   images (.EXE) are available.  Use with OSSL or
#                   OSSLD.
#
#    WGET_ZLIB=dev:[dir]  LINK with zlib compression library.  This
#                         option may be needed if using OpenSSL, and
#                   OpenSSL was built with zlib support.  It may also be
#                   desired, if Gzip-compressed WARC files are desired.
#                   The value of the MMS macro WGET_ZLIB ("dev:[dir]",
#                   or a suitable logical name) tells where to find the
#                   zlib object library (LIBZ.OLB).  The library is
#                   expected to be in a "[.dest]" directory under that
#                   one ("dev:[dir.ALPHAL]", for example), or in that
#                   directory itself.
#
# Default target:
#
#    The default target, ALL, builds all the product executables.
#
# Other targets:
#
#    CLEAN      deletes architecture-specific files, but leaves any
#               individual source dependency files.
#
#    CLEAN_ALL  deletes all generated files, except the main (collected)
#               source dependency files.
#
#    CLEAN_EXE  deletes only the architecture-specific executables.
#               Handy if all you wish to do is re-link the executables.
#
#    CLEAN_OLB  deletes only the architecture-specific object libraries.
#
#    DASHV      generates a "wget -V" report.
#
#    HELP       creates the HELP library, [.vms]WGET.HLB.
#
# Example commands:
#
# To build the large-file product (except on VAX) using the
# DEC/Compaq/HP C compiler (Note: DESCRIP.MMS is the default description
# file name.):
#
#    MMS
#
# To get the small-file executable (on a non-VAX system):
#
#    MMS /MACRO = (NOLARGE=1)
#
# To build with the -d/--debug option disabled:
#
#    MMS /MACRO = (NODASHD=1)                           ! Normal.
#
#    MMS /MACRO = (NODASHD=1, NOLARGE=1)                ! Non-VAX,
#                                                       ! small-file.
#
# To delete the architecture-specific generated files for this system
# type:
#
#    MMS /DESCRIP = [.VMS] CLEAN
#    MMS /DESCRIP = [.VMS] /MACRO = (NOLARGE=1) CLEAN   ! Non-VAX,
#                                                       ! small-file.
#
# To build a normal product for debug with compiler listings and link
# maps:
#
#    MMS /DESCRIP = [.VMS] CLEAN
#    MMS /DESCRIP = [.VMS] /MACRO = (DBG=1, LIST=1)
#
########################################################################

# Include primary product description file.

INCL_DESCRIP_SRC = 1
.INCLUDE descrip_src.mms

# Generated header files.

#    Products.

SRC_CONFIG_H = $(DIR_SRC_DEST)CONFIG.H

#    Sources.

SRC_CONFIG_H_SRC = [-.$(DIR_VMS)]CONFIG.H_VMS


# TARGETS.

# Default subsidiary targets.

# Build LIB object library (default target).

.IFDEF TARGET_LIB               # TARGET_LIB

SUBSIDIARY = 1

LIBLIB : $(LIB_LIB)
	@ write sys$output ""
	@ write sys$output "   LIBLIB done."
	@ write sys$output ""

$(LIB_LIB) : $(LIB_LIB)($(MODS_OBJS_LIB_LIB))
	@ write sys$output "$(MMS$TARGET) updated."

# Special rules for MD5.C on VAX where Compaq C V6.4-005
# (like, probably, other versions) loops with /optimize = disjoint.

.IFDEF __VAX__                      # __VAX__

[.$(DEST)]MD5.OBJ : MD5.C
	@ write sys$output "***************************************"
	@ write sys$output "* Note: Exceptional rule in use here: *"
	@ write sys$output "***************************************"
	$(CC) $(CFLAGS) /optimize = nodisjoint /define = ($(CDEFS)) -
	 $(MMS$SOURCE)

.ENDIF                              # __VAX__

.ENDIF                          # TARGET_LIB


# Build Wget executable or SRC object library (default target).

.IFDEF TARGET_SRC               # TARGET_SRC

SUBSIDIARY = 1

EXES : $(EXES)
	@ write sys$output ""
	@ write sys$output "   Wget done."
	@ write sys$output ""

$(LIB_SRC) : $(LIB_SRC)($(MODS_OBJS_LIB_SRC))
	@ write sys$output "$(MMS$TARGET) updated."

$(WGET_EXE) : $(LIB_LIB) $(LIB_SRC)
	$(LINK) $(LINKFLAGS) -
	 $(LIB_SRC) /library /include = (main), -
	 $(LIB_LIB) /library -
	 $(SSL_LINK_OPT) -
	 $(ZLIB_LINK_OPT) -
	 $(LFLAGS_ARCH)

$(DECC_VER_EXE) : $(DECC_VER_OBJ)
	$(LINK) $(LINKFLAGS) -
	 $(DECC_VER_OBJ) -
	 $(LFLAGS_ARCH)

$(DECC_VER_OBJ) : [-.$(DIR_SRC)]DECC_VER.C

.ENDIF                          # TARGET_SRC


# Default global target.

ALL : $(EXES)
	@ show time
	@ write sys$output ""
	@ write sys$output "   ALL done."
	@ write sys$output ""

# Global rules for executables and object libraries.

.IFDEF TARGET_LIB               # TARGET_LIB
.ELSE                           # TARGET_LIB

$(LIB_LIB) : GENERATED_HEADERS
	dev_dir = f$environment( "DEFAULT")
	set default 'f$parse( "$(MMSDESCRIPTION_FILE)", , , "DIRECTORY")'
	set default [-.$(DIR_LIB)]
	show default
	@ write sys$output ""
.IFDEF CHECK_LARGE              # CHECK_LARGE
	if (NO_LARGE_DCL_SYM .gt. 0) then NOLARGE = 1
	if (NO_LARGE_DCL_SYM .le. 0) then LARGE = 1
.ENDIF                          # CHECK_LARGE
	$(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
	 $(LIB_LIB)
	set default 'dev_dir'
	show default
	@ write sys$output ""

.ENDIF                          # TARGET_LIB [else]

.IFDEF TARGET_SRC               # TARGET_SRC
.ELSE                           # TARGET_SRC

$(LIB_SRC) : GENERATED_HEADERS
	dev_dir = f$environment( "DEFAULT")
	set default 'f$parse( "$(MMSDESCRIPTION_FILE)", , , "DIRECTORY")'
	set default [-.$(DIR_SRC)]
	show default
	@ write sys$output ""
.IFDEF CHECK_LARGE              # CHECK_LARGE
	if (NO_LARGE_DCL_SYM .gt. 0) then NOLARGE = 1
	if (NO_LARGE_DCL_SYM .le. 0) then LARGE = 1
.ENDIF                          # CHECK_LARGE
	$(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
	 $(LIB_SRC)
	set default 'dev_dir'
	show default
	@ write sys$output ""

$(WGET_EXE) :
        set default 'f$parse( "$(MMSDESCRIPTION_FILE)", , , "DIRECTORY")'
        set default [-.$(DIR_SRC)]
        show default
        @ write sys$output ""
.IFDEF CHECK_LARGE              # CHECK_LARGE
	if (NO_LARGE_DCL_SYM .gt. 0) then NOLARGE = 1
	if (NO_LARGE_DCL_SYM .le. 0) then LARGE = 1
.ENDIF                          # CHECK_LARGE
        $(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
         $(WGET_EXE)

$(DECC_VER_EXE) :
        set default 'f$parse( "$(MMSDESCRIPTION_FILE)", , , "DIRECTORY")'
        set default [-.$(DIR_SRC)]
        show default
        @ write sys$output ""
.IFDEF CHECK_LARGE              # CHECK_LARGE
	@ if (NO_LARGE_DCL_SYM .gt. 0) then NOLARGE = 1
	@ if (NO_LARGE_DCL_SYM .le. 0) then LARGE = 1
.ENDIF                          # CHECK_LARGE
        $(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
         $(DECC_VER_EXE)

.ENDIF                          # TARGET_SRC [else]



# CLEAN target.  Delete the [.$(DEST)] directory and everything in it.

.IFDEF SUBSIDIARY               # SUBSIDIARY

CLEAN :
	if (f$search( "[.$(DEST)]*.*") .nes. "") then -
	 delete [.$(DEST)]*.*;*
	if (f$search( "$(DEST).dir", 1) .nes. "") then -
	 set protection = w:d $(DEST).dir;*
	if (f$search( "$(DEST).dir", 2) .nes. "") then -
	 delete $(DEST).dir;*

# CLEAN_ALL target.  Delete:
#    The [...$(DEST)] directories and everything in them.
#    All individual C dependency files.
#    The help library.
# Also mention:
#    Comprehensive dependency file.

CLEAN_ALL :
	@ write sys$output "   SUBS - CLEAN_ALL"
	show default
	@ write sys$output ""
	if (f$search( "[...ALPHA*]*.*") .nes. "") then -
	 delete [...ALPHA*]*.*;*
	if (f$search( "[...]ALPHA*.dir", 1) .nes. "") then -
	 set protection = w:d [...]ALPHA*.dir;*
	if (f$search( "[...]ALPHA*.dir", 2) .nes. "") then -
	 delete [...]ALPHA*.dir;*
	if (f$search( "[...IA64*]*.*") .nes. "") then -
	 delete [...IA64*]*.*;*
	if (f$search( "[...]IA64*.dir", 1) .nes. "") then -
	 set protection = w:d [...]IA64*.dir;*
	if (f$search( "[...]IA64*.dir", 2) .nes. "") then -
	 delete [...]IA64*.dir;*
	if (f$search( "[...VAX*]*.*") .nes. "") then -
	 delete [...VAX*]*.*;*
	if (f$search( "[...]VAX*.dir", 1) .nes. "") then -
	 set protection = w:d [...]VAX*.dir;*
	if (f$search( "[...]VAX*.dir", 2) .nes. "") then -
	 delete [...]VAX*.dir;*
	if (f$search( "[...]*.MMSD") .nes. "") then -
	 delete [...]*.MMSD;*
	@ ! The help library can be deleted from anywhere.
	if (f$search( "$(WGET_HLB)") .nes. "") then -
	 delete $(WGET_HLB);*
	@ write sys$output ""
	@ write sys$output "Note:  This procedure will not"
	@ write sys$output "   DELETE DESCRIP_DEPS.MMS;*"
	@ write sys$output -
 "You may choose to, but a recent version of MMS (V3.5 or newer?) is"
	@ write sys$output -
 "needed to regenerate it.  (It may also be recovered from the original"
	@ write sys$output -
 "distribution kit.)  See DESCRIP_MKDEPS.MMS for instructions on"
	@ write sys$output -
 "generating DESCRIP_DEPS.MMS."
	@ write sys$output ""

# CLEAN_EXE target.  Delete the executables in [.$(DEST)].

CLEAN_EXE :
	if (f$search( "[.$(DEST)]*.EXE") .nes. "") then -
	 delete [.$(DEST)]*.EXE;*

# CLEAN_OLB target.  Delete the object libraries in [.$(DEST)].

CLEAN_OLB :
	if (f$search( "[.$(DEST)]*.OLB") .nes. "") then -
	 delete [.$(DEST)]*.OLB;*

.ELSE                           # SUBSIDIARY

.IFDEF MMSTARGETS                   # MMSTARGETS

#
# MMS (or MMK) with the MMSTARGETS macro needs only one real CLEAN rule.
#

CLEAN, CLEAN_ALL, CLEAN_EXE, CLEAN_OLB :
	set default 'f$parse( "$(MMSDESCRIPTION_FILE)", , , "DIRECTORY")'
	set default [-.$(DIR_LIB)]
	show default
	@ write sys$output ""
.IFDEF CHECK_LARGE              # CHECK_LARGE
	@ if (NO_LARGE_DCL_SYM .gt. 0) then NOLARGE = 1
	@ if (NO_LARGE_DCL_SYM .le. 0) then LARGE = 1
.ENDIF                          # CHECK_LARGE
	$(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
	 $(MMSTARGETS)
	set default [-.$(DIR_SRC)]
	show default
	@ write sys$output ""
	$(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
	 $(MMSTARGETS)

.ELSE                               # MMSTARGETS

#
# MMK without the MMSTARGETS macro needs more rules.
#

CLEAN :
	set default 'f$parse( "$(MMSDESCRIPTION_FILE)", , , "DIRECTORY")'
	set default [-.$(DIR_LIB)]
	show default
	@ write sys$output ""
.IFDEF CHECK_LARGE              # CHECK_LARGE
	@ if (NO_LARGE_DCL_SYM .gt. 0) then NOLARGE = 1
	@ if (NO_LARGE_DCL_SYM .le. 0) then LARGE = 1
.ENDIF                          # CHECK_LARGE
	$(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
	 CLEAN
	set default [-.$(DIR_SRC)]
	show default
	@ write sys$output ""
	$(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
	 CLEAN

CLEAN_ALL :
	set default 'f$parse( "$(MMSDESCRIPTION_FILE)", , , "DIRECTORY")'
	set default [-.$(DIR_LIB)]
	show default
	@ write sys$output ""
.IFDEF CHECK_LARGE              # CHECK_LARGE
	@ if (NO_LARGE_DCL_SYM .gt. 0) then NOLARGE = 1
	@ if (NO_LARGE_DCL_SYM .le. 0) then LARGE = 1
.ENDIF                          # CHECK_LARGE
	$(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
	 CLEAN_ALL
	set default [-.$(DIR_SRC)]
	show default
	@ write sys$output ""
	$(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
	 CLEAN_ALL

CLEAN_EXE :
	set default 'f$parse( "$(MMSDESCRIPTION_FILE)", , , "DIRECTORY")'
	set default [-.$(DIR_LIB)]
	show default
	@ write sys$output ""
.IFDEF CHECK_LARGE              # CHECK_LARGE
	@ if (NO_LARGE_DCL_SYM .gt. 0) then NOLARGE = 1
	@ if (NO_LARGE_DCL_SYM .le. 0) then LARGE = 1
.ENDIF                          # CHECK_LARGE
	$(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
	 CLEAN_EXE
	set default [-.$(DIR_SRC)]
	show default
	@ write sys$output ""
	$(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
	 CLEAN_EXE

CLEAN_OLB :
	set default 'f$parse( "$(MMSDESCRIPTION_FILE)", , , "DIRECTORY")'
	set default [-.$(DIR_LIB)]
	show default
	@ write sys$output ""
.IFDEF CHECK_LARGE              # CHECK_LARGE
	@ if (NO_LARGE_DCL_SYM .gt. 0) then NOLARGE = 1
	@ if (NO_LARGE_DCL_SYM .le. 0) then LARGE = 1
.ENDIF                          # CHECK_LARGE
	$(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
	 CLEAN_OLB
	set default [-.$(DIR_SRC)]
	show default
	@ write sys$output ""
	$(MMS) /description = $(MMSDESCRIPTION_FILE) $(MMSQUALIFIERS) -
	 CLEAN_OLB

.ENDIF                              # MMSTARGETS [else]

.ENDIF                          # SUBSIDIARY

DEFAULT :
	@ write sys$output "No target, specified or default."

# DASHV target.  Generate a "wget -V" report.

DASHV :
        mcr $(DIR_SRC_DEST)wget "-V"

# HELP target.  Generate the HELP library source files.

HELP : $(WGET_HLB)
	@ write sys$output ""
	@ write sys$output "   ""$<"" is ready."
	@ write sys$output ""

$(WGET_HLB) : $(WGET_HLP)
	LIBRARY /CREATE /HELP $(MMS$TARGET) $(MMS$SOURCE)

# Default C compile rule.

.C.OBJ :
	$(CC) $(CFLAGS) /define = ($(CDEFS)) $(MMS$SOURCE)


# Generated header files.

GENERATED_HEADERS : $(SRC_CONFIG_H)
	@ write sys$output "$(MMS$TARGET) updated."

$(DIR_SRC_DEST_FILE) :
	if (f$search( "$(DIR_SRC_DEST_FILE)") .eqs. "") then -
	 create /directory $(DIR_SRC_DEST)

# Copy the VMS-specific configuration file ("vms/config.h_vms") to the
# destination directory.

$(SRC_CONFIG_H) : $(SRC_CONFIG_H_SRC) $(DIR_SRC_DEST_FILE)
	copy /nolog $(MMS$SOURCE) $(MMS$TARGET)


# Include generated source dependencies.

.IFDEF SUBSIDIARY               # SUBSIDIARY

INCL_DESCRIP_DEPS = 1

.INCLUDE descrip_deps.mms

.ENDIF                          # SUBSIDIARY

